package com.caimei365.order.mapper;

import com.caimei365.order.model.bo.ReceiptParamsBo;
import com.caimei365.order.model.po.ReceiptPo;
import com.caimei365.order.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/2/11
 */
@Mapper
public interface ReceiptMapper {
    /**
     * 保存收款记录
     */
    void insertReceipt(ReceiptPo receiptPo);
    /**
     * 更新收款记录
     */
    void updateReceipt(ReceiptPo receiptPo);
    /**
     * 根据openid获取收款用户
     */
    ReceiptUserVo getReceiptUserByOpenid(String openId);
    /**
     * 根据mobile获取收款用户
     */
    ReceiptUserVo getReceiptUserByMobile(String mobile);
    /**
     * 根据mobile更新openid
     */
    void updateOpenidByMobile(String openid, String unionId, String mobile);
    /**
     * 获取用户权限: 1录入收款权限，2收款确认权限，3收款审核权限 4返佣管理权限 5供应商退款管理权限
     */
    List<Integer> getPermissionsByUserId(Integer userId);
    /**
     * 获取收款类型列表
     */
    List<ReceiptTypeVo> getReceiptType();
    /**
     * 获取收款类型
     */
    ReceiptTypeVo getReceiptTypeById(Integer id);
    /**
     * 短信内容Md5加密串 获取收款记录
     */
    List<ReceiptVo> getReceiptBySmsMd5Code(String smsMd5Code);
    /**
     * 获取收款类型
     */
    Integer getReceivablesTypeId(String type);
    /**
     * 获取订单已支付金额(待审核状态的收款也算)
     */
    Double getPaidAmountByOrderId(Integer orderId);
    /**
     * 获取订单待审核金额
     */
    Double getUncheckAmount(Integer orderId);
    /**
     * 获取订单已退金额
     */
    Double getReturnedAmount(Integer orderId);
    /**
     * 获取主订单下面的所有的确认收货商品数量
     */
    Integer getReceiptNumByOrderId(Integer orderId);
    /**
     * 获取该主订单下面所有已完成状态退货退款商品数量
     */
    Integer getReturnAndCancelNum(Integer orderId);
    /**
     * 获取协销Id
     */
    Integer getServiceProviderId(String unionId);
    /**
     * 获取协销下的机构userIds
     */
    List<Integer> getClubUserIdBySpId(Integer spId);
    /**
     * 获取收款列表
     */
    List<ReceiptVo> getReceiptList(ReceiptParamsBo receiptParamsBo);
    /**
     * 获取收款详情
     */
    ReceiptVo getReceiptDetail(Integer id);
    /**
     * 获取收款关联订单
     */
    List<OrderVo> getReceiptOrders(Integer receiptId);
    /**
     * 获取收款商品订单列表
     */
    List<OrderVo> getOrderListByParams(ReceiptParamsBo receiptParamsBo);
    List<OrderVo> getOrderListByOrderIds(@Param("orderIdS") String[] orderIdS);
    /**
     * 存在退款中的记录
     */
    Integer countHaveReturning(Integer orderId);
    /**
     * 存在收款中的记录
     */
    Integer countHaveReceipting(Integer orderId);
    /**
     * 线上支付收款Id
     */
    Integer getOnlineReceiptId(Integer orderId);
    /**
     * 获取已退款金额
     */
    List<ReturnedPurchaseVo> getRefundFeeByOrderId(Integer orderId);
    /**
     * 已关联子订单
     */
    List<ShopOrderVo> getShopOrderListByReceiptId(Integer receiptId);
    /**
     * 搜索子订单进行关联
     */
    List<ShopOrderVo> getRefundShopOrders(Integer confirmedType, String shopName, String userName, Integer orderId);
    /**
     * 返佣款-子订单列表
     */
    List<ShopOrderVo> getRebateShopOrders(String shopName);
    /**
     * 返佣订单付款总金额
     */
    double countAllPayAssociateAmount(Integer orderId);
    /**
     * 需要支付金额
     */
    double countNeedPayAmount(Integer orderId);
    /**
     * 删除之前与这个收款所有的关系
     */
    void deleteReceiptRelation(Integer receiptId);
    /**
     * 子订单付款类型列表
     */
    List<Integer> getRebatePayTypeList(Integer shopOrderId);

}
